@@ -6,15 +6,14 @@ use Carp ();
 use HTTP::Date qw(str2time);
 use base qw( Exporter );
 
-our $VERSION = '6.08_01';
-$VERSION =~ tr/_//d;
-sub Version { $VERSION; }
+# ABSTRACT: Parse directory listing
+our $VERSION = '6.09_01'; # TRIAL VERSION
+$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
+
+sub Version { $File::Listing::VERSION; }
 
 our @EXPORT = qw(parse_dir);
 
-
-
-
 sub parse_dir ($;$$$)
 {
    my($dir, $tz, $fstype, $error) = @_;
@@ -56,10 +55,10 @@ sub file_mode ($)
     s/[Ll](...)$/S$1/;
 
     while (/(.)/g) {
-	$mode <<= 1;
-	$mode |= 1 if $1 ne "-" &&
-		      $1 ne 'S' &&
-		      $1 ne 'T';
+        $mode <<= 1;
+        $mode |= 1 if $1 ne "-" &&
+                      $1 ne 'S' &&
+                      $1 ne 'T';
     }
 
     $mode |= 0004000 if /^..s....../i;
@@ -112,17 +111,17 @@ sub parse
    my @files = ();
    if (ref($dir) eq 'ARRAY') {
        for (@$dir) {
-	   push(@files, $pkg->line($_, $tz, $error));
+           push(@files, $pkg->line($_, $tz, $error));
        }
    }
    else {
        local($_);
-       while (<$dir>) {
-	   chomp;
-	   push(@files, $pkg->line($_, $tz, $error));
+       while (my $line = <$dir>) {
+           chomp $line;
+           push(@files, $pkg->line($line, $tz, $error));
        }
    }
-   wantarray ? @files : \@files;
+   wantarray ? @files : \@files;  ## no critic (Freenode::Wantarray)
 }
 
 
@@ -153,42 +152,42 @@ sub line
 
     my ($kind, $size, $date, $name);
     if (($kind, $size, $date, $name) =
-	/^([\-FlrwxsStTdD]{10})                   # Type and permission bits
-	 .*                                       # Graps
-	 \D(\d+)                                  # File size
-	 \s+                                      # Some space
-	 (\w{3}\s+\d+\s+(?:\d{1,2}:\d{2}|\d{4})|\d{4}-\d{2}-\d{2}\s+\d{2}:\d{2})  # Date
-	 \s+                                      # Some more space
-	 (.*)$                                    # File name
-	/x )
+        /^([\-FlrwxsStTdD]{10})                   # Type and permission bits
+         .*                                       # Graps
+         \D(\d+)                                  # File size
+         \s+                                      # Some space
+         (\w{3}\s+\d+\s+(?:\d{1,2}:\d{2}|\d{4})|\d{4}-\d{2}-\d{2}\s+\d{2}:\d{2})  # Date
+         \s+                                      # Some more space
+         (.*)$                                    # File name
+        /x )
 
     {
-	return if $name eq '.' || $name eq '..';
-	$name = "$curdir/$name" if length $curdir;
-	my $type = '?';
-	if ($kind =~ /^l/ && $name =~ /(.*) -> (.*)/ ) {
-	    $name = $1;
-	    $type = "l $2";
-	}
-	elsif ($kind =~ /^[\-F]/) { # (hopefully) a regular file
-	    $type = 'f';
-	}
-	elsif ($kind =~ /^[dD]/) {
-	    $type = 'd';
-	    $size = undef;  # Don't believe the reported size
-	}
-	return [$name, $type, $size, str2time($date, $tz),
+        return if $name eq '.' || $name eq '..';
+        $name = "$curdir/$name" if length $curdir;
+        my $type = '?';
+        if ($kind =~ /^l/ && $name =~ /(.*) -> (.*)/ ) {
+            $name = $1;
+            $type = "l $2";
+        }
+        elsif ($kind =~ /^[\-F]/) { # (hopefully) a regular file
+            $type = 'f';
+        }
+        elsif ($kind =~ /^[dD]/) {
+            $type = 'd';
+            $size = undef;  # Don't believe the reported size
+        }
+        return [$name, $type, $size, str2time($date, $tz),
               File::Listing::file_mode($kind)];
 
     }
     elsif (/^(.+):$/ && !/^[dcbsp].*\s.*\s.*:$/ ) {
-	my $dir = $1;
-	return () if $dir eq '.';
-	$curdir = $dir;
-	return ();
+        my $dir = $1;
+        return () if $dir eq '.';
+        $curdir = $dir;
+        return ();
     }
     elsif (/^[Tt]otal\s+(\d+)$/ || /^\s*$/) {
-	return ();
+        return ();
     }
     elsif (/not found/    || # OSF1, HPUX, and SunOS return
              # "$file not found"
@@ -199,16 +198,16 @@ sub line
              /cannot find/     # Windows NT returns
              # "The system cannot find the path specified."
              ) {
-	return () unless defined $error;
-	&$error($_) if ref($error) eq 'CODE';
-	warn "Error: $_\n" if $error eq 'warn';
-	return ();
+        return () unless defined $error;
+        &$error($_) if ref($error) eq 'CODE';
+        warn "Error: $_\n" if $error eq 'warn';
+        return ();
     }
     elsif ($_ eq '') {       # AIX, and Linux return nothing
-	return () unless defined $error;
-	&$error("No such file or directory") if ref($error) eq 'CODE';
-	warn "Warning: No such file or directory\n" if $error eq 'warn';
-	return ();
+        return () unless defined $error;
+        &$error("No such file or directory") if ref($error) eq 'CODE';
+        warn "Warning: No such file or directory\n" if $error eq 'warn';
+        return ();
     }
     else {
         # parse failed, check if the dosftp parse understands it
@@ -257,24 +256,24 @@ sub line
          (.+)$                                    # File name
         /x )
     {
-	return if $name eq '.' || $name eq '..';
-	$name = "$curdir/$name" if length $curdir;
-	my $type = '?';
-	if ($size_or_dir eq '<DIR>') {
-	    $type = "d";
+        return if $name eq '.' || $name eq '..';
+        $name = "$curdir/$name" if length $curdir;
+        my $type = '?';
+        if ($size_or_dir eq '<DIR>') {
+            $type = "d";
             $size = ""; # directories have no size in the pc listing
         }
         else {
-	    $type = 'f';
+            $type = 'f';
             $size = $size_or_dir;
-	}
-	return [$name, $type, $size, str2time($date, $tz), undef];
+        }
+        return [$name, $type, $size, str2time($date, $tz), undef];
     }
     else {
-	return () unless defined $error;
-	&$error($_) if ref($error) eq 'CODE';
-	warn "Can't parse: $_\n" if $error eq 'warn';
-	return ();
+        return () unless defined $error;
+        &$error($_) if ref($error) eq 'CODE';
+        warn "Can't parse: $_\n" if $error eq 'warn';
+        return ();
     }
 
 }
@@ -282,10 +281,10 @@ sub line
 
 
 package File::Listing::vms;
-@File::Listing::vms::ISA = qw(File::Listing);
+our @ISA = qw(File::Listing);
 
 package File::Listing::netware;
-@File::Listing::netware::ISA = qw(File::Listing);
+our @ISA = qw(File::Listing);
 
 
 
@@ -304,31 +303,31 @@ sub line {
 
     s!</?t[rd][^>]*>! !g;  # clean away various table stuff
     if (m!<A\s+HREF=\"([^\"]+)\">.*</A>.*?(\d+)-([a-zA-Z]+|\d+)-(\d+)\s+(\d+):(\d+)\s+(?:([\d\.]+[kMG]?|-))!i) {
-	my($filename, $filesize) = ($1, $7);
-	my($d,$m,$y, $H,$M) = ($2,$3,$4,$5,$6);
-	if ($m =~ /^\d+$/) {
-	    ($d,$y) = ($y,$d) # iso date
-	}
-	else {
-	    $m = _monthabbrev_number($m);
-	}
+        my($filename, $filesize) = ($1, $7);
+        my($d,$m,$y, $H,$M) = ($2,$3,$4,$5,$6);
+        if ($m =~ /^\d+$/) {
+            ($d,$y) = ($y,$d) # iso date
+        }
+        else {
+            $m = _monthabbrev_number($m);
+        }
 
-	$filesize = 0 if $filesize eq '-';
-	if ($filesize =~ s/k$//i) {
-	    $filesize *= 1024;
-	}
-	elsif ($filesize =~ s/M$//) {
-	    $filesize *= 1024*1024;
-	}
-	elsif ($filesize =~ s/G$//) {
-	    $filesize *= 1024*1024*1024;
-	}
-	$filesize = int $filesize;
+        $filesize = 0 if $filesize eq '-';
+        if ($filesize =~ s/k$//i) {
+            $filesize *= 1024;
+        }
+        elsif ($filesize =~ s/M$//) {
+            $filesize *= 1024*1024;
+        }
+        elsif ($filesize =~ s/G$//) {
+            $filesize *= 1024*1024*1024;
+        }
+        $filesize = int $filesize;
 
-	require Time::Local;
-	my $filetime = Time::Local::timelocal(0,$M,$H,$d,$m-1,_guess_year($y));
-	my $filetype = ($filename =~ s|/$|| ? "d" : "f");
-	return [$filename, $filetype, $filesize, $filetime, undef];
+        require Time::Local;
+        my $filetime = Time::Local::timelocal(0,$M,$H,$d,$m-1,_guess_year($y));
+        my $filetype = ($filename =~ s|/$|| ? "d" : "f");
+        return [$filename, $filetype, $filesize, $filetime, undef];
     }
 
     return ();
@@ -348,12 +347,12 @@ sub _guess_year {
     # where apache provides two digit dates so I am leaving this as-is
     # for now.  Possibly the right thing is to not handle two digit years.
     } elsif ($y >= 90) {
-	$y = 1900+$y;
+        $y = 1900+$y;
     }
 
     # TODO: likewise assuming 00-89 are 20xx is long term probably wrong.
     elsif ($y < 100) {
-	$y = 2000+$y;
+        $y = 2000+$y;
     }
     $y;
 }
@@ -381,16 +380,24 @@ sub _monthabbrev_number {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 File::Listing - Parse directory listing
 
+=head1 VERSION
+
+version 6.09_01
+
 =head1 SYNOPSIS
 
  use File::Listing qw(parse_dir);
  $ENV{LANG} = "C";  # dates in non-English locales not supported
  foreach my $file (parse_dir(`ls -l`)) {
-     ($name, $type, $size, $mtime, $mode) = @$file;
+     my ($name, $type, $size, $mtime, $mode) = @$file;
      next if $type ne 'f'; # plain file
      #...
  }
@@ -488,13 +495,25 @@ Provides the same interface but uses XS and the parser implementation from C<ftp
 
 =back
 
-=head1 COPYRIGHT
+=head1 AUTHORS
 
-Copyright 1996-2010, Gisle Aas
-Copyright 2020 Graham Ollis
+=over 4
 
-Based on lsparse.pl (from Lee McLoughlin's ftp mirror package) and
-L<Net::FTP>'s parse_dir (Graham Barr).
+=item *
 
-This library is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
+Gisle Aas
+
+=item *
+
+Graham Ollis <plicease@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 1996-2020 by Gisle Aas.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
